︠a6ff1b15-9c34-41a5-8d7a-0bafe432b0c0is︠
def latex_integral(f, *limits):
    r"""
    Produce a `\LaTeX` expression of computing the iterated integral.

    .. warning::

        This function tries to plow through all obstacles and, in particular, will try to use the Fundamental Theorem of Calculus even if the function is not integrable on the given interval. In this case a red question mark will appear over an equality sign: `\int_-1^1 \frac{1}{x}\, dx =^{\color{red}?} 0`. This behaviour is necessary, for example, to compute the volume of a unit sphere as a triple iterated integral with square roots in limits.

    INPUT:

    - ``f`` -- a function to integrate;

    - ``*limits`` -- a sequence of triples `(v, a, b)` corresponding to `\int_a^b \dots\, dv`, internal integrals must be first.

    OUTPUT:

    - a :class:`LatexExpr`.

    EXAMPLES::

        sage: var("x, y, z")
        sage: latex_integral(1, (y, -sqrt(1-x^2-z^2), sqrt(1-x^2-z^2)), (x, 0, sqrt(1-z^2)), (z, -1, 1))
    """
    integrand = SR(f)
    integrals = []
    differentials = []
    expressions = [integrand]
    for v, a, b in limits:
        integrals.insert(0, r"\int_{%s}^{%s} " % (latex(a), latex(b)))
        differentials.append(r"\, d %s" % latex(v))
        expressions.extend([a, b])
        try:
            assume(a < v)
            assume(v < b)
        except ValueError:
            pass
    # We also assume that everything is nicely computable in a calculus course...
    w0 = SR.wild(0)
    w1 = SR.wild(1)
    while expressions:
        current = expressions.pop(0)
        if current in RDF:
            continue
        # sqrt(4-x^2) is real!!!
        for m in current.find(w0^w1):
            m = m.match(w0^w1)
            expressions.extend(m.values())
            if m[w0] not in RDF and (m[w1] not in QQ or is_even(QQ(m[w1]).denominator())):
                try:
                    assume(m[w0] > 0)
                except ValueError:
                    pass

    result = [r"\displaystyle"]
    try:
        n = len(limits)
        for i in range(n):
            result.extend(integrals[:n-i])
            s = latex(integrand)
            inside = 0
            for c in s:
                if c in "([{":
                    inside += 1
                elif c in ")]}":
                    inside -= 1
                elif c in "+-" and inside == 0:
                    s = r"\left( %s \right)" % s
                    break
            result.append(s)
            result.extend(differentials[i:])
            result.append("=")
            v, a, b = limits[i]
            try:
                integrand = integral(integrand, v, a, b)
            except (RuntimeError, ValueError):
                integrand = integral(integrand, v)
                if "integrate" in str(integrand):
                    # Does now work well with substitution, give up.
                    raise ValueError("cannot integrate given function")
                integrand = integrand.subs({v: b}) - integrand.subs({v: a})
                # Use FTC, even if integrand is not integrable, but put a warning.
                result[-1] = r"\, {\color{red}{=^?}} \,"
            try:
                integrand = integrand.simplify_full()
            except AttributeError:
                pass
        result.append(latex(integrand))
        if integrand not in ZZ and integrand in RDF:
            result.append(r"\approx")
            result.append(latex(integrand.n()))
    except  (AttributeError, RuntimeError, TypeError, ValueError):
        result.append(r"\dots ?")
    forget()
    return LatexExpr(" ".join(result))


from sage.plot.misc import setup_for_eval_on_grid


def plot_vector_field3d(functions, xrange, yrange, zrange,
                        plot_points=5, colors='jet', center_arrows=False,**kwds):
    try:
        from matplotlib.cm import get_cmap
        cm = get_cmap(colors)
    except (TypeError, ValueError):
        cm = None
    if cm is None:
        if isinstance(colors, (list, tuple)):
            from matplotlib.colors import LinearSegmentedColormap
            cm = LinearSegmentedColormap.from_list('mymap',colors)
        else:
            cm = lambda x: colors

    (ff,gg,hh), ranges = setup_for_eval_on_grid(functions, [xrange, yrange, zrange], plot_points)
    xpoints, ypoints, zpoints = [srange(*r, include_endpoint=True) for r in ranges]
    V = VectorSpace(RDF, 3)
    points = [V((i,j,k)) for i in xpoints for j in ypoints for k in zpoints]
    vectors = [V((ff(*point), gg(*point), hh(*point))) for point in points]

    size = 0.9 * max(r[-1] for r in ranges)
    norms = [sqrt(v*v) for v in vectors]
    max_norm = max(norms)
    scaled_vectors = [v/max_norm*size for v in vectors]
    if center_arrows:
        points = [p - v/2 for p, v in zip(points, scaled_vectors)]
    return sum([arrow3d((0,0,0), v, color=cm(n/max_norm), **kwds).translate(p) for p, v, n in zip(points, scaled_vectors, norms)])


def plot_vector_field3d_along_curve(field, curve, trange, plot_points=20, colors='jet', center_arrows=False,  **kwds):
    r"""
    Plot a 3D vector field along a parametric curve `C`.

    INPUT:

    - ``field`` -- a list of three functions of `(x, y, z)` specifying the vector field;

    - ``curve`` -- a list of three functions of a single variable, parametric equations of `C`;

    - ``trange`` -- a triple `(t, start, end)`, the variable and interval of parametrization of `C`;

    - ``plot_points`` (default: 20) -- the number of arrows to plot `C`;

    - ``colors`` (default: 'jet') -- a color, list of colors (which are
      interpolated between), or matplotlib colormap name, giving the coloring
      of the arrows.  If a list of colors or a colormap is given,
      coloring is done as a function of length of the vector

    - ``center_arrows`` (default: ``False``) -- if ``True``, draw the arrows
      centered on the points; otherwise, draw the arrows with the tails
      at the points;

    - any other keywords are passed on to the plot command for each arrow.

    OUTPUT:

    - a plot.

    EXAMPLES::

    """
    try:
        from matplotlib.cm import get_cmap
        cm = get_cmap(colors)
    except (TypeError, ValueError):
        cm = None
    if cm is None:
        if isinstance(colors, (list, tuple)):
            from matplotlib.colors import LinearSegmentedColormap
            cm = LinearSegmentedColormap.from_list('mymap',colors)
        else:
            cm = lambda x: colors

    curve_d = dict(zip(map(SR, "xyz"), curve))
    field = [c.subs(curve_d) for c in field]
    (P, Q, R, x, y, z), (trange, ) = setup_for_eval_on_grid(field + list(curve), [trange], plot_points)
    trange = srange(*trange, include_endpoint=True)
    V = VectorSpace(RDF, 3)
    points = [V((x(t), y(t), z(t))) for t in trange]
    vectors = [V((P(t), Q(t), R(t))) for t in trange]

    size = max([max(vlist) - min(vlist) for vlist in zip(*points)]) / sqrt(plot_points)
    norms = [sqrt(v*v) for v in vectors]
    max_norm = max(norms)
    scaled_vectors = [v/max_norm*size for v in vectors]
    if center_arrows:
        points = [p - v/2 for p, v in zip(points, scaled_vectors)]
    return sum([arrow3d((0,0,0), v, color=cm(n/max_norm), **kwds).translate(p) for p, v, n in zip(points, scaled_vectors, norms)])


def plot_vector_field3d_along_surface(F, r, urange, vrange, plot_points=10, colors='jet', center_arrows=False, plot_surface=None, plot_ulines=None, plot_vlines=None, **kwds):
    r"""
    Plot a 3D vector field along a parametric curve `S`.

    INPUT:

    - ``F`` -- a list of three functions of `(x, y, z)` specifying the vector field;

    - ``r`` -- a list of three functions of two variables, parametric equations of `S`;

    - ``urange``, ``vrange`` -- triples `(u, start, end)`, `(v, start, end)`, the variables and intervals of parametrization of `S`;

    - ``plot_points`` (default: 10) -- the number of arrows to plot;

    - ``colors`` (default: 'jet') -- a color, list of colors (which are
      interpolated between), or matplotlib colormap name, giving the coloring
      of the arrows.  If a list of colors or a colormap is given,
      coloring is done as a function of length of the vector

    - ``center_arrows`` (default: ``False``) -- if ``True``, draw the arrows
      centered on the points; otherwise, draw the arrows with the tails
      at the points;

    - any other keywords are passed on to the plot command for each arrow.

    OUTPUT:

    - a plot.

    EXAMPLES::

    """
    try:
        from matplotlib.cm import get_cmap
        cm = get_cmap(colors)
    except (TypeError, ValueError):
        cm = None
    if cm is None:
        if isinstance(colors, (list, tuple)):
            from matplotlib.colors import LinearSegmentedColormap
            cm = LinearSegmentedColormap.from_list('mymap',colors)
        else:
            cm = lambda x: colors

    r_d = dict(zip(map(SR, "xyz"), r))
    F = [c.subs(r_d) for c in F]
    (P, Q, R, x, y, z), ranges = setup_for_eval_on_grid(F + list(r), [urange, vrange], plot_points)
    urange, vrange = [srange(*range, include_endpoint=True) for range in ranges]
    V = VectorSpace(RDF, 3)
    points = [V((x(u, v), y(u, v), z(u, v))) for u in urange for v in vrange]
    vectors = [V((P(u, v), Q(u, v), R(u, v))) for u in urange for v in vrange]
    # NaN is just impossible to detect due to RDF(NaN) == 123!!!
    vectors = [v if "NaN" not in str(v) else V.zero() for v in vectors]

    size = max([max(vlist) - min(vlist) for vlist in zip(*points)]) / max(flatten([plot_points]))
    norms = [sqrt(v*v) for v in vectors]
    max_norm = max(norms)
    scaled_vectors = [v/max_norm*size for v in vectors]
    if center_arrows:
        points = [p - v/2 for p, v in zip(points, scaled_vectors)]
    result = sum([arrow3d((0,0,0), v, color=cm(n/max_norm), **kwds).translate(p) for p, v, n in zip(points, scaled_vectors, norms)])

    options = plot_surface if isinstance(plot_surface, dict) else dict()
    if plot_surface is not None:
        result += parametric_plot_3d((x, y, z), urange, vrange, **plot_surface)

    options = plot_ulines if isinstance(plot_ulines, dict) else dict()
    if plot_ulines is not None:
        for U in urange:
            result += parametric_plot3d([fast_float(c.subs(u=U), "v") for c in r], (vrange[0], vrange[-1]), **plot_ulines)

    options = plot_vlines if isinstance(plot_vlines, dict) else dict()
    if plot_vlines is not None:
        for V in vrange:
            result += parametric_plot3d([fast_float(c.subs(v=V), "u") for c in r], (urange[0], urange[-1]), **plot_vlines)

    return result


def add_axes(p):
    r"""
    """
    bb = p.bounding_box()
    for i, v in enumerate("XYZ"):
        start = min(bb[0][i], 0)
        end = max(bb[1][i], 0)
        length = end - start
        p += line([[0]*i+[start-0.08*length]+[0]*(2-i), [0]*i+[end+0.08*length]+[0]*(2-i)], thickness=3, color="brown")
        p += text3d(v, [0]*i+[end+0.1*length]+[0]*(2-i))
    return p


t, u, v, x, y, z = map(SR.var, "tuvxyz")


def to_value(l):
    return map(SR, map(str, l[0]))


html(r"""
<style>.control {display:inline-block; vertical-align:middle;}</style>

<table>
<tr>
    <td><div class="control" id="plot_field"/></td>
    <td>Plot vector field $\vec{F}(x,y,z)$ <div class="control" id="field_style"/></td>
</tr>
<tr><td></td>
    <td><div class="control" id="Fx"/> $\vec{i} +$ <div class="control" id="Fy"/> $\vec{j} +$ <div class="control" id="Fz"/> $\vec{k}$</td>
</tr>
<tr><td></td>
    <td>
    Box:
    <div class="control" id="x_min"/> $\leq x \leq$ <div class="control" id="x_max"/>$,\quad$
    <div class="control" id="y_min"/> $\leq y \leq$ <div class="control" id="y_max"/>$,\quad$
    <div class="control" id="z_min"/> $\leq z \leq$ <div class="control" id="z_max"/>
    </td>
</tr>
<tr>
    <td><div class="control" id="plot_curve"/></td>
    <td>Plot parametric curve $C$ given by $\vec{r}(t)$ for
        <div class="control" id="t_min"/> $\leq t \leq$ <div class="control" id="t_max"/></td>
</tr>
<tr><td></td>
    <td><div class="control" id="Cx"/> $\vec{i} +$ <div class="control" id="Cy"/> $\vec{j} +$ <div class="control" id="Cz"/> $\vec{k}$</td>
</tr>
<tr>
    <td><div class="control" id="plot_surface"/></td>
    <td>Plot parametric surface $S$ given by $\vec{r}(u, v)$ for
        <div class="control" id="u_min"/> $\leq u \leq$ <div class="control" id="u_max"/>$,\quad$
        <div class="control" id="v_min"/> $\leq v \leq$ <div class="control" id="v_max"/></td>
</tr>
<tr><td></td>
    <td><div class="control" id="Sx"/> $\vec{i} +$ <div class="control" id="Sy"/> $\vec{j} +$ <div class="control" id="Sz"/> $\vec{k}$</td>
</tr>
</table>

<div class="control" id="plot_axes"/>Axes
<div class="control" id="plot_origin"/>Origin
<div class="control" id="plot_normals"/>Unit normals to $S$
<div class="control" id="compute"/>Try to compute flux/circulation
<div class="control" id="auto_update"/>

<div id="_output"/>
""")

component_width = 25

@interact
def _(
      plot_field=checkbox(),
      field_style=selector(["around C and S", "along C", "along S", "in given box"], default="around C and S"),
      Fx=input_box(default=2*y, width=component_width),
      Fy=input_box(default=3*x, width=component_width),
      Fz=input_box(default=x+y, width=component_width),
      x_min=input_box(default=-1, width=5),
      x_max=input_box(default=1, width=5),
      y_min=input_box(default=-1, width=5),
      y_max=input_box(default=1, width=5),
      z_min=input_box(default=-1, width=5),
      z_max=input_box(default=1, width=5),

      plot_curve=checkbox(),
      Cx=input_box(default=(2+sin(t/2))*cos(t), width=component_width),
      Cy=input_box(default=(2+sin(t/2))*sin(t), width=component_width),
      Cz=input_box(default=cos(t/2), width=component_width),
      t_min=input_box(default=0, width=5),
      t_max=input_box(default=4*pi, width=5),

      plot_surface=checkbox(),
      Sx=input_box(default=(2+v*sin(u/2))*cos(u), width=component_width),
      Sy=input_box(default=(2+v*sin(u/2))*sin(u), width=component_width),
      Sz=input_box(default=v*cos(u/2), width=component_width),
      u_min=input_box(default=0, width=5),
      u_max=input_box(default=2*pi, width=5),
      v_min=input_box(default=-1, width=5),
      v_max=input_box(default=1, width=5),

      plot_axes=checkbox(),
      plot_origin=checkbox(),
      plot_normals=checkbox(False),
      compute=checkbox(False),
      auto_update=False,
      ):
    F = vector(SR, (Fx, Fy, Fz))
    C = vector(SR, (Cx, Cy, Cz))
    S = vector(SR, (Sx, Sy, Sz))
    trange = (t, t_min, t_max)
    urange = (u, u_min, u_max)
    vrange = (v, v_min, v_max)
    orientation=(-211, -554, -805, 145) # First quadrant by default
    p = Graphics()
    if plot_curve:
        p += parametric_plot3d(C, trange, thickness=5, color="blue")
        for endpoint in trange[1:]:
            p += point([c.subs(t=endpoint) for c in C], size=15, color="red")
    if plot_surface:
        p += parametric_plot3d(S, urange, vrange, color="gold", opacity=0.75)
        r_u = diff(S, u)
        r_v = diff(S, v)
        sigma = r_u.cross_product(r_v)
        n = sigma / sigma.norm()
        if plot_normals:
            p += plot_vector_field3d_along_surface(n, S, urange, vrange, colors="black", plot_ulines={"color": "green"}, plot_vlines={"color": "green"})
    if plot_field:
        if field_style == "in given box":
            limits = [[x, x_min, x_max], [y, y_min, y_max], [z, z_min, z_max]]
        elif not plot_curve and not plot_surface:
            print "You must plot C to plot the vector field along or around it!"
            # For "along" we want it still to pick orientation.
            return
        else:
            limits = map(list, zip([x, y, z], *p.bounding_box()))
        # This perturbation allows plotting "2d" plots.
        plot_points = [5, 5, 5] # Default for 3D
        M = max(abs(s - e) for v, s, e in limits)
        for i in range(3):
            if limits[i][1] == limits[i][2]:
                orientation=[(1,1,1, -120), (1,0,0,-90), (0, 0, 0, 0)][i]
                limits[i][2] += M / 1000
                plot_points[i] = 1
                for j in range(3):
                    if plot_points[j] == 5:
                        plot_points[j] = 10
        if field_style == "along C":
            p += plot_vector_field3d_along_curve(F, C, trange)
        elif field_style == "along S":
            p += plot_vector_field3d_along_surface(F, S, urange, vrange, plot_ulines={"color": "green"}, plot_vlines={"color": "green"})
        else:
            p += plot_vector_field3d(F, *limits, plot_points=plot_points)
    if plot_origin:
        p += point3d((0, 0, 0), size=25, color="yellow")
    if plot_axes:
        p = add_axes(p)
    print "showing 3d plot..."
    show(p, frame=False, aspect_ratio=1)
    if compute:
        if plot_curve:
            sd = dict(zip([x, y, z], C))
            I = latex_integral((F*C.diff(t)).subs(sd), trange)
            html(r"\[ \int_C \vec{F}\cdot d\vec{r} = %s \]" % I)
            if (C[2] == 0 and
                F[2] == 0 and
                C.subs(t=trange[1]) == C.subs(t=trange[2])):
                I = latex_integral((F[0]*diff(C[1], t) - F[1]*diff(C[0], t)).subs(sd), trange)
                html(r"\[ \oint_C \vec{F}\cdot \vec{n}\, ds = %s \]" % I)
        if plot_surface:
            sd = dict(zip([x, y, z], S))
            I = latex_integral((F*sigma).subs(sd), urange, vrange)
            html(r"\[ \iint_S \vec{F}\cdot d\vec{S} = %s \]" % I)

html(r"""
<h2>Notes</h2>

<ul>
<li>If you have vanishing denominators and things don't work, try to change $xyz$-limits a little, e.g. $\vec{F} = (1/x, 0, 0)$ does not work for $x$ limits $[-1,1]$, but $[-1.1, 1]$ is OK.</li>
<li>To work with 2D curves and fields (and to compute the flux across $C$), set $z$-components to zero.</li>
</ul>
""")
︡ce1a3669-0243-4174-90ca-f4b1d8fb8fff︡{"html":"\n<style>.control {display:inline-block; vertical-align:middle;}</style>\n\n<table>\n<tr>\n    <td><div class=\"control\" id=\"plot_field\"/></td>\n    <td>Plot vector field $\\vec{F}(x,y,z)$ <div class=\"control\" id=\"field_style\"/></td>\n</tr>\n<tr><td></td>\n    <td><div class=\"control\" id=\"Fx\"/> $\\vec{i} +$ <div class=\"control\" id=\"Fy\"/> $\\vec{j} +$ <div class=\"control\" id=\"Fz\"/> $\\vec{k}$</td>\n</tr>\n<tr><td></td>\n    <td>\n    Box:\n    <div class=\"control\" id=\"x_min\"/> $\\leq x \\leq$ <div class=\"control\" id=\"x_max\"/>$,\\quad$\n    <div class=\"control\" id=\"y_min\"/> $\\leq y \\leq$ <div class=\"control\" id=\"y_max\"/>$,\\quad$\n    <div class=\"control\" id=\"z_min\"/> $\\leq z \\leq$ <div class=\"control\" id=\"z_max\"/>\n    </td>\n</tr>\n<tr>\n    <td><div class=\"control\" id=\"plot_curve\"/></td>\n    <td>Plot parametric curve $C$ given by $\\vec{r}(t)$ for\n        <div class=\"control\" id=\"t_min\"/> $\\leq t \\leq$ <div class=\"control\" id=\"t_max\"/></td>\n</tr>\n<tr><td></td>\n    <td><div class=\"control\" id=\"Cx\"/> $\\vec{i} +$ <div class=\"control\" id=\"Cy\"/> $\\vec{j} +$ <div class=\"control\" id=\"Cz\"/> $\\vec{k}$</td>\n</tr>\n<tr>\n    <td><div class=\"control\" id=\"plot_surface\"/></td>\n    <td>Plot parametric surface $S$ given by $\\vec{r}(u, v)$ for\n        <div class=\"control\" id=\"u_min\"/> $\\leq u \\leq$ <div class=\"control\" id=\"u_max\"/>$,\\quad$\n        <div class=\"control\" id=\"v_min\"/> $\\leq v \\leq$ <div class=\"control\" id=\"v_max\"/></td>\n</tr>\n<tr><td></td>\n    <td><div class=\"control\" id=\"Sx\"/> $\\vec{i} +$ <div class=\"control\" id=\"Sy\"/> $\\vec{j} +$ <div class=\"control\" id=\"Sz\"/> $\\vec{k}$</td>\n</tr>\n</table>\n\n<div class=\"control\" id=\"plot_axes\"/>Axes\n<div class=\"control\" id=\"plot_origin\"/>Origin\n<div class=\"control\" id=\"plot_normals\"/>Unit normals to $S$\n<div class=\"control\" id=\"compute\"/>Try to compute flux/circulation\n<div class=\"control\" id=\"auto_update\"/>\n\n<div id=\"_output\"/>\n"}︡{"interact":{"style":"None","flicker":false,"layout":[[["plot_field",12,null]],[["field_style",12,null]],[["Fx",12,null]],[["Fy",12,null]],[["Fz",12,null]],[["x_min",12,null]],[["x_max",12,null]],[["y_min",12,null]],[["y_max",12,null]],[["z_min",12,null]],[["z_max",12,null]],[["plot_curve",12,null]],[["Cx",12,null]],[["Cy",12,null]],[["Cz",12,null]],[["t_min",12,null]],[["t_max",12,null]],[["plot_surface",12,null]],[["Sx",12,null]],[["Sy",12,null]],[["Sz",12,null]],[["u_min",12,null]],[["u_max",12,null]],[["v_min",12,null]],[["v_max",12,null]],[["plot_axes",12,null]],[["plot_origin",12,null]],[["plot_normals",12,null]],[["compute",12,null]],[["auto_update",12,null]],[["",12,null]]],"id":"684cd13b-4460-405a-b07c-d6978386dcf4","controls":[{"default":true,"var":"plot_field","readonly":false,"control_type":"checkbox","label":"plot_field"},{"buttons":false,"control_type":"selector","ncols":null,"button_classes":null,"default":0,"lbls":["around C and S","along C","along S","in given box"],"label":"field_style","nrows":null,"width":null,"var":"field_style"},{"control_type":"input-box","default":"2*y","label":"Fx","nrows":1,"width":25,"readonly":false,"submit_button":null,"var":"Fx","type":null},{"control_type":"input-box","default":"3*x","label":"Fy","nrows":1,"width":25,"readonly":false,"submit_button":null,"var":"Fy","type":null},{"control_type":"input-box","default":"x + y","label":"Fz","nrows":1,"width":25,"readonly":false,"submit_button":null,"var":"Fz","type":null},{"control_type":"input-box","default":-1,"label":"x_min","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"x_min","type":null},{"control_type":"input-box","default":1,"label":"x_max","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"x_max","type":null},{"control_type":"input-box","default":-1,"label":"y_min","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"y_min","type":null},{"control_type":"input-box","default":1,"label":"y_max","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"y_max","type":null},{"control_type":"input-box","default":-1,"label":"z_min","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"z_min","type":null},{"control_type":"input-box","default":1,"label":"z_max","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"z_max","type":null},{"default":true,"var":"plot_curve","readonly":false,"control_type":"checkbox","label":"plot_curve"},{"control_type":"input-box","default":"(sin(1/2*t) + 2)*cos(t)","label":"Cx","nrows":1,"width":25,"readonly":false,"submit_button":null,"var":"Cx","type":null},{"control_type":"input-box","default":"(sin(1/2*t) + 2)*sin(t)","label":"Cy","nrows":1,"width":25,"readonly":false,"submit_button":null,"var":"Cy","type":null},{"control_type":"input-box","default":"cos(1/2*t)","label":"Cz","nrows":1,"width":25,"readonly":false,"submit_button":null,"var":"Cz","type":null},{"control_type":"input-box","default":0,"label":"t_min","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"t_min","type":null},{"control_type":"input-box","default":"4*pi","label":"t_max","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"t_max","type":null},{"default":true,"var":"plot_surface","readonly":false,"control_type":"checkbox","label":"plot_surface"},{"control_type":"input-box","default":"(v*sin(1/2*u) + 2)*cos(u)","label":"Sx","nrows":1,"width":25,"readonly":false,"submit_button":null,"var":"Sx","type":null},{"control_type":"input-box","default":"(v*sin(1/2*u) + 2)*sin(u)","label":"Sy","nrows":1,"width":25,"readonly":false,"submit_button":null,"var":"Sy","type":null},{"control_type":"input-box","default":"v*cos(1/2*u)","label":"Sz","nrows":1,"width":25,"readonly":false,"submit_button":null,"var":"Sz","type":null},{"control_type":"input-box","default":0,"label":"u_min","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"u_min","type":null},{"control_type":"input-box","default":"2*pi","label":"u_max","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"u_max","type":null},{"control_type":"input-box","default":-1,"label":"v_min","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"v_min","type":null},{"control_type":"input-box","default":1,"label":"v_max","nrows":1,"width":5,"readonly":false,"submit_button":null,"var":"v_max","type":null},{"default":true,"var":"plot_axes","readonly":false,"control_type":"checkbox","label":"plot_axes"},{"default":true,"var":"plot_origin","readonly":false,"control_type":"checkbox","label":"plot_origin"},{"default":false,"var":"plot_normals","readonly":false,"control_type":"checkbox","label":"plot_normals"},{"default":false,"var":"compute","readonly":false,"control_type":"checkbox","label":"compute"},{"default":false,"var":"auto_update","readonly":false,"control_type":"checkbox","label":"auto_update"}]}}︡{"html":"\n<h2>Notes</h2>\n\n<ul>\n<li>If you have vanishing denominators and things don't work, try to change $xyz$-limits a little, e.g. $\\vec{F} = (1/x, 0, 0)$ does not work for $x$ limits $[-1,1]$, but $[-1.1, 1]$ is OK.</li>\n<li>To work with 2D curves and fields (and to compute the flux across $C$), set $z$-components to zero.</li>\n</ul>\n"}︡
︠9ad5b65a-a64f-49b6-91fe-4e618ee84815︠









